/*
 * GPIO.h
 *
 *      Author: Aleksey Gerasimenko
 *      gerasimenko.aleksey.n@gmail.com
 */

#include "F28335/DSP28x_Project.h"

#include "DSP28335/CPUBase.h"

#ifndef DSP28335_GPIO_H_
#define DSP28335_GPIO_H_

namespace DSP28335
{

typedef void (*pGPIO_FUNCTION)();

class GPIO: public DSP28335::CPUBase
{
public:
    GPIO();
    //EPWM
    static void gpio_epwm_setup();
    //
    //CAN Inteface
    static void gpio_cana_setup();
    static void gpio_canb_setup();
    //
    //SCIA
    static void gpio_scia_setup();
    //
    //RS485 - SCIB external - HMI
    static void gpio_scib_setup();
    static void gpio_scib_re_de_setup();
    static void gpio_scib_re_de_set();
    static void gpio_scib_re_de_clear();
    //
    //RS485 - SCIC internal
    static void gpio_scic_setup();
    //
    //FRAM - SPIA
    static void gpio_spia_setup();
    static void gpio_spia_write_protect_set();
    static void gpio_spia_write_protect_clear();
    //
    // EQEP
    static void gpio_eqep_setup();
    //
    // XINTF
    static void gpio_xintf_16bit_setup();
    static void gpio_xintf_32bit_setup();
    //
    // GPIO
    static void gpio_dicrete_outputs_setup();
    //
    // EXTERNAL ADC
    static void ext_adc_start_convertion_setup();
    static void set_ext_adc_start_convertion();
    static void clear_ext_adc_start_convertion();
    //
    // Hard Fault
    static void gpio_hard_fault_setup();
    static void gpio_hard_fault_read(uint16_t& data);
    //
    // Analog Fault Current Sensors
    static void gpio_analog_fault_setup();
    static void gpio_analog_fault_read(uint16_t& data);
    //
};//class GPIO()

} /* namespace DSP28335 */

#endif /* DSP28335_GPIO_H_ */
